"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.aggregateCSVReports = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const report_to_row_1 = require("./report-to-row");
const sync_1 = __importDefault(require("csv-stringify/lib/sync"));
/**
 * @returns the stringified CSV with the aggregated reports.
 */
exports.aggregateCSVReports = (reportsDirectoryPath) => {
    let files;
    try {
        files = fs_1.default.readdirSync(reportsDirectoryPath);
    }
    catch (error) {
        console.error(error);
        return false;
    }
    const rows = [];
    let headers = null;
    try {
        files.forEach((fileName) => {
            if (fileName !== '.DS_Store') {
                const filePath = path_1.default.join(reportsDirectoryPath, fileName);
                const fileContents = fs_1.default.readFileSync(filePath, { encoding: 'utf-8' });
                // If headers aren't set yet, do it now
                headers = headers || report_to_row_1.reportToRowHeaders(fileContents);
                console.log(`Bundling ${fileName} into aggregated report`);
                const newRow = report_to_row_1.reportToRow(fileContents);
                if (newRow) {
                    rows.push(newRow);
                }
                else {
                    console.log(`Failed to bundle: ${fileName}`);
                }
            }
        });
        rows.unshift(headers);
        return sync_1.default(rows);
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
