"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.crawl = void 0;
const simplecrawler_1 = __importDefault(require("simplecrawler"));
const emitter_1 = require("./emitter");
const utilities_1 = require("./utilities");
exports.crawl = (siteUrl, opts) => {
    const { on, emit, promise } = emitter_1.createEmitter();
    const crawler = new simplecrawler_1.default(siteUrl);
    if (opts.userAgent)
        crawler.userAgent = opts.userAgent;
    crawler.respectRobotsTxt = !opts.ignoreRobotsTxt;
    const emitWarning = (queueItem, response) => {
        emit('warning', `Error fetching (${response.statusCode}): ${queueItem.url}`);
    };
    crawler.on('fetchcomplete', (queueItem, responseBuffer, response) => {
        const url = queueItem.url;
        const contentType = response.headers['content-type'];
        if (!utilities_1.isContentTypeHtml(contentType))
            return;
        const statusCode = response.statusCode;
        if (!contentType || !statusCode)
            return;
        emit('urlFound', url, contentType, responseBuffer.length, statusCode);
    });
    crawler.on('complete', () => emit('resolve'));
    crawler.on('fetcherror', emitWarning);
    crawler.on('fetch404', emitWarning);
    crawler.on('fetch410', emitWarning);
    crawler.start();
    return { on, promise };
};
