"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scan = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const lighthouse_1 = require("./lighthouse");
const combine_1 = require("./combine");
const crawl_1 = require("./crawl");
const emitter_1 = require("./emitter");
exports.scan = (siteUrl, { crawler = crawl_1.crawl, lighthouse = lighthouse_1.runLighthouseReport, dataDirectory, ...opts }) => {
    const { promise, on, emit } = emitter_1.createEmitter();
    // Set up for lighthouse reports
    const reportDirName = 'reports';
    const reportsDirPath = `${dataDirectory}/${reportDirName}`;
    fs_1.default.mkdirSync(dataDirectory, { recursive: true });
    /** Used so we can display an error if no pages are found while crawling */
    let hasFoundAnyPages = false;
    emit('info', 'Starting the crawl...');
    const crawlerEmitter = crawler(siteUrl, opts);
    crawlerEmitter.on('urlFound', (url, contentType, bytes, statusCode) => {
        hasFoundAnyPages = true;
        emit('urlFound', url, contentType, bytes, statusCode);
        lighthouse(url)
            .then((reportData) => {
            emit('reportComplete', url, reportData);
        })
            .catch((error) => emit('warning', error));
    });
    crawlerEmitter.on('warning', (message) => emit('warning', message));
    crawlerEmitter.promise.then(() => {
        emit('info', 'Scan complete');
        if (!hasFoundAnyPages) {
            emit('warning', `No pages were found for this site. The two most likely reasons for this are:
1) the URL is incorrect
2) the crawler is being denied by a robots.txt file`);
            return;
        }
        emit('info', 'Aggregating reports...');
        // TODO: Make aggregateCSVReports work without filesystem, for testing
        const aggregatedReportData = combine_1.aggregateCSVReports(reportsDirPath);
        if (!aggregatedReportData)
            return;
        const writePath = path_1.default.join(dataDirectory, 'aggregatedMobileReport.csv');
        fs_1.default.writeFile(writePath, aggregatedReportData, (e) => {
            if (e)
                emit('warning', e);
        });
        emit('info', 'DONE!');
    });
    return { promise, on };
};
